( cd usr/lib64 ; rm -rf libgrilo-0.3.so )
( cd usr/lib64 ; ln -sf libgrilo-0.3.so.0 libgrilo-0.3.so )
( cd usr/lib64 ; rm -rf libgrilo-0.3.so.0 )
( cd usr/lib64 ; ln -sf libgrilo-0.3.so.0.315.1 libgrilo-0.3.so.0 )
( cd usr/lib64 ; rm -rf libgrlnet-0.3.so )
( cd usr/lib64 ; ln -sf libgrlnet-0.3.so.0 libgrlnet-0.3.so )
( cd usr/lib64 ; rm -rf libgrlnet-0.3.so.0 )
( cd usr/lib64 ; ln -sf libgrlnet-0.3.so.0.315.0 libgrlnet-0.3.so.0 )
( cd usr/lib64 ; rm -rf libgrlpls-0.3.so )
( cd usr/lib64 ; ln -sf libgrlpls-0.3.so.0 libgrlpls-0.3.so )
( cd usr/lib64 ; rm -rf libgrlpls-0.3.so.0 )
( cd usr/lib64 ; ln -sf libgrlpls-0.3.so.0.315.0 libgrlpls-0.3.so.0 )
